@@ -266,14 +266,32 @@ XC_UNPOLARIZED = 0
 XC_POLARIZED = 1
 
 
+def _import_pylibxc():
+  """Load the LibXC Python bindings module.
+
+  The distribution published to PyPI will be named ``pylibxc3``, but it
+  exposes the importable module ``pylibxc`` (matching the upstream
+  LibXC project). For local development, users may also have installed
+  a legacy ``pylibxc`` build directly.
+  """
+  try:
+    import pylibxc  # type: ignore[import-not-found]
+    return pylibxc
+  except Exception as e:
+    raise RuntimeError(
+      "The 'pylibxc' module is required to allocate LibXC functionals. "
+      "Install it via the 'pylibxc3' wheels on PyPI or a local build."
+    ) from e
+
+
 def list_functionals() -> list[str]:
   """Return all LibXC functional names known to JXC.
 
   This is a lightweight convenience wrapper around LibXC's registry:
 
-  - If :mod:`pylibxc` is available, we return the list from
+  - If :mod:`pylibxc3` or :mod:`pylibxc` is available, we return the list from
     ``pylibxc.util.xc_available_functional_names()``, sorted.
-  - If :mod:`pylibxc` is not available, we fall back to scanning the
+  - If neither binding is available, we fall back to scanning the
     ``jxc.functionals`` package for generated Maple modules.
 
   Returns:
@@ -281,8 +299,7 @@ def list_functionals() -> list[str]:
     ``\"gga_x_pbe\"``, ``\"hyb_gga_xc_b3lyp\"``).
   """
   try:
-    import pylibxc
-
+    pylibxc = _import_pylibxc()
     return sorted(pylibxc.util.xc_available_functional_names())
   except Exception:
     # Minimal, best-effort fallback based on generated modules.
@@ -348,10 +365,11 @@ def get_params(name, polarized, *ext_params, _visited=None):
   if name in _M06_PARAM_SETS:
     return _build_m06_variant(name, polarized, _visited)
   try:
-    import pylibxc
+    pylibxc = _import_pylibxc()
   except Exception as e:
     raise RuntimeError(
-      "pylibxc is required to allocate LibXC functionals"
+      "The 'pylibxc' module is required to allocate LibXC functionals. "
+      "Install it via the 'pylibxc3' wheels on PyPI or a local build."
     ) from e
   try:
     from . import helper as _helper
